==> haskell-should-not-typecheck-2.1.0-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-should-not-typecheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: should-not-typecheck
version: 2.1.0
id: should-not-typecheck-2.1.0-AwxUwXui1bvjOOhQtCNby
key: should-not-typecheck-2.1.0-AwxUwXui1bvjOOhQtCNby
license: BSD-3-Clause
maintainer: message.me.on@github.com
author: Callum Rogers
homepage: http://github.com/CRogers/should-not-typecheck
synopsis: A HUnit/hspec assertion library to verify that an expression does not typecheck
description:
    For examples and an introduction to the library please take a look at the <https://github.com/CRogers/should-not-typecheck#should-not-typecheck- README> on github.
category: Testing
abi: 3298c05a72702838fef7a45aa0f39fd7
exposed: True
exposed-modules:
    Test.ShouldNotTypecheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/should-not-typecheck-2.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/should-not-typecheck-2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/should-not-typecheck-2.1.0
hs-libraries: HSshould-not-typecheck-2.1.0-AwxUwXui1bvjOOhQtCNby
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj base-4.12.0.0 deepseq-1.4.4.0
haddock-interfaces: /usr/share/doc/haskell-should-not-typecheck/html/should-not-typecheck.haddock
haddock-html: /usr/share/doc/haskell-should-not-typecheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-should-not-typecheck-2.1.0-35-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-should-not-typecheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: should-not-typecheck
version: 2.1.0
id: should-not-typecheck-2.1.0-CMm6SGegegB9WvwG3Yt4mU
key: should-not-typecheck-2.1.0-CMm6SGegegB9WvwG3Yt4mU
license: BSD-3-Clause
maintainer: message.me.on@github.com
author: Callum Rogers
homepage: http://github.com/CRogers/should-not-typecheck
synopsis: A HUnit/hspec assertion library to verify that an expression does not typecheck
description:
    For examples and an introduction to the library please take a look at the <https://github.com/CRogers/should-not-typecheck#should-not-typecheck- README> on github.
category: Testing
abi: 01e02144cac13686693915f2b0257020
exposed: True
exposed-modules:
    Test.ShouldNotTypecheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/should-not-typecheck-2.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/should-not-typecheck-2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/should-not-typecheck-2.1.0
hs-libraries: HSshould-not-typecheck-2.1.0-CMm6SGegegB9WvwG3Yt4mU
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj base-4.12.0.0 deepseq-1.4.4.0
haddock-interfaces: /usr/share/doc/haskell-should-not-typecheck/html/should-not-typecheck.haddock
haddock-html: /usr/share/doc/haskell-should-not-typecheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
